@@ -3,11 +3,11 @@ require 'spec_helper'
 require 'acceptance/webmock_shared'
 require_relative './async_http_client_spec_helper'
 
-require 'protocol/http/body/file'
-
-Async.logger.debug! if ENV['ASYNC_LOGGER_DEBUG']
-
 unless RUBY_PLATFORM =~ /java/
+  require 'protocol/http/body/file'
+
+  Async.logger.debug! if ENV['ASYNC_LOGGER_DEBUG']
+
   describe 'Async::HTTP::Client' do
     include AsyncHttpClientSpecHelper
 
@@ -345,7 +345,7 @@ unless RUBY_PLATFORM =~ /java/
     end
 
     def make_request(method, url, protocol: nil, headers: {}, body: nil)
-      Async do
+      result  = Async do
         endpoint = Async::HTTP::Endpoint.parse(url)
 
         begin
@@ -362,6 +362,8 @@ unless RUBY_PLATFORM =~ /java/
           e
         end
       end.wait
+
+      result.is_a?(Exception) ? raise(result) : result
     end
 
     def response_to_hash(response)
